@@ -2,8 +2,8 @@ import requests
 import pyjokes
 from datetime import datetime
 from itertools import islice
-import utils
-import errors
+from .utils import correction
+from .errors import BaseError, ArgumentError
 
 URL = "http://api.brainshop.ai/get"
 
@@ -27,6 +27,7 @@ class ChatBot:
             'logs': [
             ]
         }
+        self.customdata = []
         self.__writelog(["Bot Initialised", "Bot Credentials : " + str(self.getcreds())], "logs")
 
     def getcreds(self):
@@ -45,13 +46,19 @@ class ChatBot:
 
     def spellcheck(self, val):
         if val is not True or val is not False:
-            errors.ArgumentError("Value must be boolean")
+            ArgumentError("Value must be boolean")
         self.spelling = val
 
+    def changename(self, name):
+        if not name == "":
+            self.uiid = name
+        else:
+            ArgumentError("Incorrect argument passed")
+
     def sendmsg(self, message1):
         msg = message1
         if self.spelling is True:
-            x = utils.correction(msg)
+            x = correction(msg)
             if not msg == x:
                 print("User input autocorrected")
                 self.__writelog(["Input received", "Spell Check done"], "logs")
@@ -68,7 +75,7 @@ class ChatBot:
             'msg': msg
         }
         if params['bid'] == "" or params['key'] == "" or params['uid'] == "":
-            raise errors.BaseError("ChatBot not setup properly!")
+            raise BaseError("ChatBot not setup properly!")
         elif done == 0:
             r = requests.get(url=URL, params=params)
             data = r.json()['cnt']
@@ -78,11 +85,11 @@ class ChatBot:
             self.__writelog([msg, data], "history")
             return data
         else:
-            raise errors.BaseError("Internal Error!")
+            raise BaseError("Internal Error!")
 
     def __writelog(self, data, logtype):
         if logtype == "history" and self.debug['history'] is True:
-            self.__debugdata['history'].extend(["User : " + data[0], "Bot : " + data[1]])
+            self.__debugdata['history'].extend(["User : " + data[0], self.uiid + " : " + data[1]])
         elif logtype == "logs" and self.debug['debug'] is True:
             self.__debugdata['logs'].append("[" + datetime.now().strftime("%d/%m/%Y %H:%M:%S") + "]")
             for i in data:
@@ -91,7 +98,7 @@ class ChatBot:
 
     def printlogs(self, filename="Chatbot.log"):
         if self.debug['debug'] is False:
-            raise errors.BaseError("Debug not enabled while creating bot")
+            raise BaseError("Debug not enabled while creating bot")
         f = open(filename, "w+")
         for i in self.__debugdata['logs']:
             f.write(i)
@@ -101,12 +108,12 @@ class ChatBot:
 
     def gethistory(self, length="all"):
         if self.debug['history'] is False:
-            raise errors.BaseError("History has not been enabled while creating bot")
+            raise BaseError("History has not been enabled while creating bot")
         his_len = len(self.__debugdata['history'])
         if length == "all" or length == 0:
             length = his_len
         if length > his_len or not length % 2 == 0:
-            raise errors.ArgumentError("Length argument is not even or larger than history length.")
+            raise ArgumentError("Length argument is not even or larger than history length.")
         his = self.__debugdata['history']
         data = iter(his)
         split = [his_len - length, length]
@@ -115,5 +122,9 @@ class ChatBot:
         output[1].insert(0, "Here is your History:")
         return output[1]
 
+    def adddata(self, input, output):
+        return
+        # TODO add code
+
 
 print("ChatBotAPI by HilFing initialised.\nThank you for using this library.\n\n")
